changeset 12576:b74f5036a434 v8.0.1166

patch 8.0.1166: :terminal doesn't work on Mac High Sierra commit https://github.com/vim/vim/commit/c958b316386fa44116a02bfbd5859edc54a4a7e0 Author: Bram Moolenaar <Bram@vim.org> Date: Sat Sep 30 20:04:36 2017 +0200 patch 8.0.1166: :terminal doesn't work on Mac High Sierra Problem: :terminal doesn't work on Mac High Sierra. Solution: Change #ifdef for OpenPTY(). (Ozaki Kiichi, Kazunobu Kuriyama, closes #2162)
author Christian Brabandt <cb@256bit.org>
date Sat, 30 Sep 2017 20:15:04 +0200
parents a4270d6de19a
children 146d737348b7
files src/pty.c src/version.c
diffstat 2 files changed, 5 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/src/version.c
+++ b/src/version.c
@@ -762,6 +762,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    1166,
+/**/
     1165,
 /**/
     1164,
--- a/src/pty.c
+++ b/src/pty.c
@@ -267,10 +267,11 @@ OpenPTY(char **ttyn)
 }
 #endif
 
-#if defined(HAVE_SVR4_PTYS) && !defined(PTY_DONE) && !defined(hpux) && !defined(MACOS_X)
+#if defined(HAVE_SVR4_PTYS) && !defined(PTY_DONE) && !defined(hpux) \
+                    && !(defined(MACOS_X) && !defined(MAC_OS_X_VERSION_10_6))
 
 /* NOTE: Even though HPUX can have /dev/ptmx, the code below doesn't work!
  * Same for Mac OS X Leopard. */
 #define PTY_DONE
     int
 OpenPTY(char **ttyn)
@@ -267,10 +267,11 @@ OpenPTY(char **ttyn)
 
 /* NOTE: Even though HPUX can have /dev/ptmx, the code below doesn't work!
- * Same for Mac OS X Leopard. */
+ * Same for Mac OS X Leopard (10.5). */
 #define PTY_DONE
     int